/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.service;

import se.vgregion.portal.vap.domain.jpa.UserEvents;
import se.vgregion.portal.vap.domain.searchresult.Document;

import java.util.List;

/**
 * Service interface for managing {@link UserEvents}.
 *
 * @author Patrik Bergström
 */
public interface UserEventsService {

    /**
     * Add a document so it will be the "latest" document.
     *
     * @param userId     the userId
     * @param documentId the documentId
     */
    void addDocumentEvent(long userId, String documentId);

    /**
     * Find {@link UserEvents} by userId.
     *
     * @param userId the userId
     * @return the found {@link UserEvents} or <code>null</code> if none found
     */
    UserEvents findByUserId(long userId);

    /**
     * Find the most recent {@link Document}s for a user.
     *
     * @param userId the usesrId
     * @return a {@link List} of {@link Document}s
     * @throws DocumentSearchServiceException DocumentSearchServiceException
     */
    List<Document> findRecentDocuments(long userId) throws DocumentSearchServiceException;
}
