/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.vap.service.repository;

import se.vgregion.dao.domain.patterns.repository.Repository;
import se.vgregion.portal.vap.domain.jpa.Bookmark;

import java.util.Collection;
import java.util.List;

/**
 * The base interface for managing {@link Bookmark}s.
 *
 * @author Patrik Bergström
 */
public interface BookmarkRepository extends Repository<Bookmark, Long> {

    /**
     * Find all bookmarks for a given user.
     *
     * @param userId the user's userId
     * @return a collection of {@link Bookmark}s
     */
    Collection<Bookmark> findBookmarksByUserId(Long userId);

    /**
     * Find all bookmarks for a given user and documentId. A bookmark is associated with a
     * {@link se.vgregion.portal.vap.domain.jpa.Folder} and a user can thus have several bookmarks for with a given
     * documenetId.
     *
     * @param userId the user's userId
     * @param documentId the documenetId
     * @return a collection of {@link Bookmark}s
     */
    List<Bookmark> findBookmarksByUserIdAndDocumentId(Long userId, String documentId);
}
